@@ -3,64 +3,55 @@
 """KhtEditor a source code editor by Khertan : Code Editor"""
 
 import re
-from PyQt4 import QtCore,QtGui
+from PyQt4.QtCore import *
+from PyQt4.QtGui import *
 from PyQt4.QtCore import Qt
 from plugins.plugins_api import init_plugin_system, filter_plugins_by_capability
 from recent_files import RecentFiles
 
 
-class KhtTextEdit(QtGui.QPlainTextEdit):
+class KhtTextEdit( QPlainTextEdit):
     """ Widget which handle all specifities of implemented in the editor"""
         
-    def __init__(self, parent=None, filename=QtCore.QString()):
+    def __init__(self, parent=None, filename=None):
         """Initialization, can accept a filepath as argument"""
-        QtGui.QPlainTextEdit.__init__(self, parent)
-#        self.connect(self, QtCore.SIGNAL('cursorPositionChanged()'),  self.highlightCurrentLine);
+        QPlainTextEdit.__init__(self, parent)
+#        self.connect(self,  SIGNAL('cursorPositionChanged()'),  self.highlightCurrentLine);
 
-        self.hl_color = QtGui.QColor('lightblue').lighter(120)
+        self.hl_color =  QColor('lightblue').lighter(120)
+        
         # Brace matching
         self.bracepos = None
-        # Init scroller
+        
+        # Init scroller and area which are tricky hack to speed scrolling
         scroller = None
-        #Plugin init move to editor_window.py        
+        area = None
+        
+        #Plugin init moved to editor_window.py        
         #initialization init of plugin system
         #Maybe be not the best place to do it ... 
         #init_plugin_system({'plugin_path': '/home/opt/khteditor/plugins',
         #                    'plugins': ['autoindent']})
-                            
+        
         #If we have a filename
         self.filename = filename
-        if self.filename.isEmpty():
-            self.filename = QtCore.QString("Unnamed.txt")
+        if (self.filename == None) or (self.filename == ''):
+            self.filename = u'Unnamed.txt'
         self.document().setModified(False)
         parent.setWindowTitle(self.filename)
         
-        #Maemo Finger Kinetic Scrolling
-#        scroller = self.property("kineticScroller").toPyObject()
-#        print 'Class kineticScrolling',type(scroller),':',dir(scroller)
-#        scroller.reset()
-#        scroller.setEnabled(True)
-#        scroller.setDragInertia(0.85)
-#        scroller.setMinimumVelocity(0)
-#        scroller.setMaximumVelocity(0.5)
-#        scroller.setDecelerationFactor(0.99)
-#        scroller.setFastVelocityFactor(0.99)
-#        scroller.setMode(1)
-#        print scroller.decelerationFactor()
-#        print scroller.fastVelocityFactor()
-#        print scroller.maximumVelocity()
-#        print scroller.minimumVelocity()
-#        print scroller.dragInertia()
-#        self.setWidgetResizable(True)
-
         #Set no wrap
-        if (parent.settings.value("WrapLine").toBool()):
-            self.setLineWrapMode(QtGui.QPlainTextEdit.WidgetWidth)            
+        if (bool(parent.settings.value("WrapLine"))):
+            self.setLineWrapMode( QPlainTextEdit.NoWrap)                        
         else:
-            self.setLineWrapMode(QtGui.QPlainTextEdit.NoWrap)
+            self.setLineWrapMode( QPlainTextEdit.WidgetWidth)
 
         #Get Font Size
-        fontsize = parent.settings.value("FontSize").toInt()[0]
+        try:
+            fontsize = int(parent.settings.value("FontSize"))
+        except:
+            fontsize = 11
+            
         if fontsize==0:
             fontsize=11
         #Get Font
@@ -69,7 +60,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         except:
             fontname = 'Monospace'
         #Set Font
-        self.document().setDefaultFont(QtGui.QFont(fontname,fontsize))
+        self.document().setDefaultFont( QFont(fontname,fontsize))
         
 
         #Remove auto capitalization
@@ -94,16 +85,15 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         fr = self.frameRect()
         cr = self.contentsRect()
         self.setMinimumHeight(max(s.height(), s.height() + (fr.height() - cr.height() - 1)))
-        print s.width(),s.width() + (fr.width()-cr.width()) - 1
         self.setMinimumWidth(max(s.width(),s.width() + (fr.width()-cr.width()) - 1))
 
     def ensureVisible(self,pos,xmargin,ymargin):
 
         visible = self.area.viewport().size()        
-        currentPos = QtCore.QPoint(self.area.horizontalScrollBar().value(),
+        currentPos =  QPoint(self.area.horizontalScrollBar().value(),
                       self.area.verticalScrollBar().value())
-        posRect = QtCore.QRect(pos.x()-xmargin, pos.y()-ymargin,2*xmargin,2*ymargin)
-        visibleRect = QtCore.QRect(currentPos, visible)
+        posRect =  QRect(pos.x()-xmargin, pos.y()-ymargin,2*xmargin,2*ymargin)
+        visibleRect =  QRect(currentPos, visible)
 
         if (visibleRect.contains(posRect)):
             return
@@ -125,40 +115,19 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         self.highlightCurrentLine()
         
         #Make sure cursor is visible
-#        cursor = 
-#        pos = self.pos()
-        #scroller = self.parentWidget().property("kineticScroller").toPyObject() 
-        #pos = self.parent().mapToParent(pos) 
-        #print type(self.parent()), type(self.parentWidget()),type(scroller)
-        #print pos, pos.x(), pos.y(), (pos + cursor.center()).y()
-        #self.scroller.ensureVisible(pos + cursor.center(), 10 + cursor.width(),
-        #                       2 * cursor.height())
-#        pw = self
+
         cursor = self.cursorRect()
         pos = cursor.center()
-#        print cursor.center(),cursor.center().x(),cursor.center().y()
         self.area.ensureVisible(pos.x(),pos.y(), 2*cursor.width()+20, 2*cursor.height())
-#        while (pw):
-#            if (pw.parentWidget()):
-#                area = pw.parentWidget()
-#                print area,area.parentWidget(),area.parent()
-#                if (type(area) == QtGui.QScrollArea ):
-#                    scroller = area.property("kineticScroller").toPyObject()
-#                    if (scroller):
-#                        print pos.x(),pos.y(),cursor.center().x(),cursor.center().y()
-#                        scroller.ensureVisible(cursor.center(), 2*cursor.width(), 2*cursor.height())
-#                    break
-#            pos = pw.mapToParent(pos)
-#            pw = pw.parentWidget()
-#
+
     #PySide Bug : The type of e is QEvent instead of QKeyEvent
     def keyPressEvent(self, event):
         """Intercept the key event to lets plugin do something if they want"""
-        if event.type() == QtCore.QEvent.KeyPress:
+        if event.type() ==  QEvent.KeyPress:
             for plugin in filter_plugins_by_capability('beforeKeyPressEvent',self.enabled_plugins):
                 plg = plugin()
                 plg.do_beforeKeyPressEvent(self,event)
-            QtGui.QPlainTextEdit.keyPressEvent(self, event)
+            QPlainTextEdit.keyPressEvent(self, event)
             for plugin in filter_plugins_by_capability('afterKeyPressEvent',self.enabled_plugins):
                 plg = plugin()
                 plg.do_afterKeyPressEvent(self,event)
@@ -166,31 +135,31 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
     def closeEvent(self,event):
         """Catch the close event and ask to save if document is modified"""
         answer = self.document().isModified() and \
-        QtGui.QMessageBox.question(self,
+        QMessageBox.question(self,
                "Text Editor - Unsaved Changes",
                "Save unsaved changes in %s?" % self.filename,
-               QtGui.QMessageBox.Yes|QtGui.QMessageBox.No|QtGui.QMessageBox.Close)
-        if answer == QtGui.QMessageBox.Yes:
+               QMessageBox.Yes| QMessageBox.No| QMessageBox.Close)
+        if answer ==  QMessageBox.Yes:
             try:
                 self.save()
                 event.accept()
             except (IOError, OSError), ioError:
-                QtGui.QMessageBox.warning(self, "Text Editor -- Save Error",
+                QMessageBox.warning(self, "Text Editor -- Save Error",
                         "Failed to save %s: %s" % (self.filename, ioError))
                 event.ignore()
-        elif answer == QtGui.QMessageBox.Close:
+        elif answer ==  QMessageBox.Close:
             return event.ignore()
         else:
             return event.accept()
 
     def save(self):
         """Hum ... just save ..."""
-        if self.filename.startsWith("Unnamed"):
+        if self.filename.startswith("Unnamed"):
             filename = self.parent().parent().parent().saveAsFile()  
-            if not filename.isEmpty():            
+            if not (filename == ''):            
                 return
             self.filename = filename
-        self.setWindowTitle(QtCore.QFileInfo(self.filename).fileName())
+        self.setWindowTitle( QFileInfo(self.filename).fileName())
         exception = None
         filehandle = None
         try:
@@ -200,10 +169,10 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
                 self.threaded_plugins.append(plg)
                 plg.do_beforeFileSave(self)
 
-            filehandle = QtCore.QFile(self.filename)
-            if not filehandle.open(QtCore.QIODevice.WriteOnly):
+            filehandle =  QFile(self.filename)
+            if not filehandle.open( QIODevice.WriteOnly):
                 raise IOError, unicode(filehandle.errorString())
-            stream = QtCore.QTextStream(filehandle)
+            stream =  QTextStream(filehandle)
             stream.setCodec("UTF-8")
             stream << self.toPlainText()
             self.document().setModified(False)
@@ -261,22 +230,22 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
                 return
     
     def __highlight(self, positions, color=None, cancel=False):
-        cursor = QtGui.QTextCursor(self.document())
+        cursor =  QTextCursor(self.document())
         modified = self.document().isModified()
         for position in positions:
             if position > self.get_position('eof'):
                 return
             cursor.setPosition(position)
-            cursor.movePosition(QtGui.QTextCursor.NextCharacter,
-                                QtGui.QTextCursor.KeepAnchor)
+            cursor.movePosition( QTextCursor.NextCharacter,
+                                 QTextCursor.KeepAnchor)
             charformat = cursor.charFormat()            
-            pen = QtGui.QPen(Qt.NoPen) if cancel else QtGui.QPen(color)
+            pen =  QPen(Qt.NoPen) if cancel else  QPen(color)
             charformat.setTextOutline(pen)
             cursor.setCharFormat(charformat)
         if cancel:
-            charformat = QtGui.QTextCharFormat()
-            cursor.movePosition(QtGui.QTextCursor.NextCharacter,
-                                QtGui.QTextCursor.KeepAnchor)
+            charformat =  QTextCharFormat()
+            cursor.movePosition( QTextCursor.NextCharacter,
+                                 QTextCursor.KeepAnchor)
             cursor.setCharFormat(charformat)            
             cursor.clearSelection()
             self.setCurrentCharFormat(charformat)
@@ -285,18 +254,18 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
             
     def highlightCurrentLine(self):            
         #Hilgight background
-        _selection = QtGui.QTextEdit.ExtraSelection()
+        _selection =  QTextEdit.ExtraSelection()
         _selection.format.setBackground(self.hl_color)
-        _selection.format.setProperty(QtGui.QTextFormat.FullWidthSelection, True)        
+        _selection.format.setProperty( QTextFormat.FullWidthSelection, True)        
         _selection.cursor = self.textCursor()
         _selection.cursor.clearSelection()
         extraSelection = []
         extraSelection.append(_selection)
 #        self.setExtraSelections(extraSelection)
 
-#        cursor = QtGui.QTextCursor(self.document())
+#        cursor =  QTextCursor(self.document())
 #        charformat = cursor.charFormat()            
-#        charformat.setTextOutline(QtGui.QPen(Qt.NoPen))            
+#        charformat.setTextOutline( QPen(Qt.NoPen))            
 #        cursor.setCharFormat(charformat)
         
         #Highlight Braces
@@ -308,8 +277,8 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         if cursor.position() == 0:
             self.setExtraSelections(extraSelection)
             return
-        cursor.movePosition(QtGui.QTextCursor.PreviousCharacter,
-                            QtGui.QTextCursor.KeepAnchor)                           
+        cursor.movePosition( QTextCursor.PreviousCharacter,
+                             QTextCursor.KeepAnchor)                           
         text = unicode(cursor.selectedText())
         pos1 = cursor.position()
         if text in (')', ']', '}'):
@@ -323,80 +292,47 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
             self.bracepos = (pos1, pos2)
 #            self.__highlight(self.bracepos, color=Qt.blue)
             print 'Bracket match'
-            _selection = QtGui.QTextEdit.ExtraSelection()
+            _selection =  QTextEdit.ExtraSelection()
             _selection.format.setForeground(Qt.white)
 #            _selection.format.setFontWeight(99)
             _selection.format.setBackground(Qt.blue)
             _selection.cursor = cursor
             extraSelection.append(_selection)
-            _selection = QtGui.QTextEdit.ExtraSelection()
+            _selection =  QTextEdit.ExtraSelection()
             _selection.format.setForeground(Qt.white)
             _selection.format.setBackground(Qt.blue)
             _selection.cursor = self.textCursor()
             _selection.cursor.setPosition(pos2)
-            _selection.cursor.movePosition(QtGui.QTextCursor.NextCharacter,
-                            QtGui.QTextCursor.KeepAnchor)
+            _selection.cursor.movePosition( QTextCursor.NextCharacter,
+                             QTextCursor.KeepAnchor)
             extraSelection.append(_selection)
         else:
             self.bracepos = (pos1,)
 #            self.__highlight(self.bracepos, color=Qt.red)
-            _selection = QtGui.QTextEdit.ExtraSelection()
+            _selection =  QTextEdit.ExtraSelection()
 #            _selection.format.setFontWeight(75)
             _selection.format.setBackground(Qt.red)
             _selection.format.setForeground(Qt.white)
-#            _selection.format.setProperty(QtGui.QTextFormat.FullWidthSelection, True)        
+#            _selection.format.setProperty( QTextFormat.FullWidthSelection, True)        
             _selection.cursor = cursor
             extraSelection.append(_selection)
             
         self.setExtraSelections(extraSelection)
-            
-#    def hilighterror(self,type,line,comment):
-#        print type,line,comment
-#        _color = QtGui.QColor()
-#        _color.setNamedColor('red')
-#        _format = QtGui.QTextCharFormat()
-#        _format.setBackground(_color)
-#        _format.setFontItalic(True)
-
-        #Hilgight background
-#        _color = QtGui.QColor()
-#        _color.setNamedColor('red')
-#        _color.lighter(160)
-#        _selection = QtGui.QTextEdit.ExtraSelection()
-#        _selection.format.setBackground(_color)
-#        _selection.format.setProperty(QtGui.QTextFormat.FullWidthSelection, true)
-#        
-#        _selection.cursor = textCursor()
-#        block = self.document().findBlockByLineNumber(line-1)        
-#        _selection.cursor.cursor.setPosition(block.position())
-#        _selection.cursor.clearSelection()
-#        self.extraSelections.append(_selection)
-#
-#Version text add
-#        block = self.document().findBlockByLineNumber(line-1)
-#        if not (block.text().startsWith('FIXME:')):
-#            block = self.document().findBlockByLineNumber(line)
-#            cursor = self.textCursor() 
-#            cursor.setPosition(block.position())
-#            cursor.insertText("FIXME:"+type+':'+str(line)+':'+comment+'\n')
-                        
-#        block.setUnderlineColor(_color)       
-#        block.setFontItalic(True)
-        
+                    
     def load(self):
         """Load ?"""
         exception = None
         filehandle = None
         try:
-            filehandle = QtCore.QFile(self.filename)
-            if not filehandle.open(QtCore.QIODevice.ReadOnly):
+            filehandle =  QFile(self.filename)
+            if not filehandle.open( QIODevice.ReadOnly):
                 raise IOError, unicode(filehandle.errorString())
-            stream = QtCore.QTextStream(filehandle)
+            stream =  QTextStream(filehandle)
             stream.setCodec("UTF-8")
-            QtGui.QApplication.processEvents()
+            QApplication.processEvents()
             self.setPlainText(stream.readAll())
             self.document().setModified(False)
-            self.setWindowTitle(QtCore.QFileInfo(self.filename).fileName())
+            self.setWindowTitle( QFileInfo(self.filename).fileName())
         except (IOError, OSError), error:
             exception = error
         finally:
@@ -413,9 +349,9 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         """UnIndent the current selection or line"""
         maincursor = self.textCursor()
         if not maincursor.hasSelection():
-            maincursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+            maincursor.movePosition( QTextCursor.StartOfBlock)
             line = str(self.document().findBlockByNumber(maincursor\
-                                      .blockNumber()).text().toUtf8())
+                                      .blockNumber()).text())
             whitespace = re.match(r"(\s{0,4})", line).group(1)
             for i in range(len(whitespace)): #@UnusedVariable
                 maincursor.deleteChar()
@@ -423,7 +359,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
             block = self.document().findBlock(maincursor.selectionStart())
             while True:
                 whitespace = re.match(r"(\s{0,4})",
-                                str(block.text().toUtf8())).group(1)
+                                str(block.text())).group(1)
                 cursor = self.textCursor() 
                 cursor.setPosition(block.position())
                 for i in range(len(whitespace)): #@UnusedVariable
@@ -436,7 +372,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         """Indent the current selection or line"""
         maincursor = self.textCursor()
         if not maincursor.hasSelection():
-            maincursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+            maincursor.movePosition( QTextCursor.StartOfBlock)
             maincursor.insertText("    ")
         else:
             block = self.document().findBlock(maincursor.selectionStart())
@@ -450,19 +386,19 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
 
     def replace_all(self, what, new, *args):
         """Replace all occurence of a search
-        arg[0] -> QtGui.QTextDocument.FindCaseSensitively
-        arg[1] -> QtGui.QTextDocument.FindWholeWords
-        arg[2] -> QtGui.QTextDocument.FindBackward
-        arg[3] -> QtGui.QTextDocument.RegEx
+        arg[0] ->  QTextDocument.FindCaseSensitively
+        arg[1] ->  QTextDocument.FindWholeWords
+        arg[2] ->  QTextDocument.FindBackward
+        arg[3] ->  QTextDocument.RegEx
         """
         # Use flags for case match
-        flags = QtGui.QTextDocument.FindFlags()
+        flags =  QTextDocument.FindFlags()
         if args[0]:
-            flags = flags|QtGui.QTextDocument.FindCaseSensitively
+            flags = flags| QTextDocument.FindCaseSensitively
         if args[1]:
-            flags = flags|QtGui.QTextDocument.FindWholeWords
+            flags = flags| QTextDocument.FindWholeWords
         if args[2]:
-            flags = flags|QtGui.QTextDocument.FindBackward
+            flags = flags| QTextDocument.FindBackward
 
         # Beginning of undo block
         pcursor = self.textCursor()
@@ -476,7 +412,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         while True:
             # self is the QTextEdit
             if args[3]:
-                cursor=self.document().find(QtCore.QRegExp(what),
+                cursor=self.document().find( QRegExp(what),
                                        cursor,flags)                
             else:
                 cursor=self.document().find(what,cursor,flags)
@@ -494,19 +430,19 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         
     def replace(self, what, new, *args):
         """Replace the first occurence of a search
-        arg[0] -> QtGui.QTextDocument.FindCaseSensitively
-        arg[1] -> QtGui.QTextDocument.FindWholeWords
-        arg[2] -> QtGui.QTextDocument.FindBackward
-        arg[3] -> QtGui.QTextDocument.RegEx
+        arg[0] ->  QTextDocument.FindCaseSensitively
+        arg[1] ->  QTextDocument.FindWholeWords
+        arg[2] ->  QTextDocument.FindBackward
+        arg[3] ->  QTextDocument.RegEx
         """
         # Use flags for case match
-        flags = QtGui.QTextDocument.FindFlags()
+        flags =  QTextDocument.FindFlags()
         if args[0]:
-            flags = flags|QtGui.QTextDocument.FindCaseSensitively
+            flags = flags| QTextDocument.FindCaseSensitively
         if args[1]:
-            flags = flags|QtGui.QTextDocument.FindWholeWords
+            flags = flags| QTextDocument.FindWholeWords
         if args[2]:
-            flags = flags|QtGui.QTextDocument.FindBackward
+            flags = flags| QTextDocument.FindBackward
 
         # Beginning of undo block
         pcursor = self.textCursor()
@@ -517,7 +453,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         # Replace
         # self is the QTextEdit
         if args[3]==True:
-            cursor = self.document().find(QtCore.QRegExp(what),
+            cursor = self.document().find( QRegExp(what),
                                     cursor, flags)                
         else:
             cursor = self.document().find(what, cursor, flags)
@@ -530,25 +466,25 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         
     def find(self, what, *args):
         """Perform a search
-        arg[0] -> QtGui.QTextDocument.FindCaseSensitively
-        arg[1] -> QtGui.QTextDocument.FindWholeWords
-        arg[2] -> QtGui.QTextDocument.FindBackward
-        arg[3] -> QtGui.QTextDocument.RegEx
+        arg[0] ->  QTextDocument.FindCaseSensitively
+        arg[1] ->  QTextDocument.FindWholeWords
+        arg[2] ->  QTextDocument.FindBackward
+        arg[3] ->  QTextDocument.RegEx
         """
         print 'find called'
         
         # Use flags for case match
-        flags = QtGui.QTextDocument.FindFlags()
+        flags =  QTextDocument.FindFlags()
         if args[0]==True:
-            flags = flags | QtGui.QTextDocument.FindCaseSensitively
+            flags = flags |  QTextDocument.FindCaseSensitively
         if args[1]==True:
-            flags = flags | QtGui.QTextDocument.FindWholeWords
+            flags = flags |  QTextDocument.FindWholeWords
         if args[2]==True:
-            flags = flags | QtGui.QTextDocument.FindBackward
+            flags = flags |  QTextDocument.FindBackward
 
         cursor = self.textCursor()
         if args[3]==True:
-            cursor = self.document().find(QtCore.QRegExp(what),
+            cursor = self.document().find( QRegExp(what),
                                        cursor , flags)
         else:
             cursor = self.document().find(what,
@@ -561,14 +497,14 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         """Duplicate the current line or selection"""
         maincursor = self.textCursor()
         if not maincursor.hasSelection():
-            maincursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+            maincursor.movePosition( QTextCursor.StartOfBlock)
             line = str(self.document().\
-                 findBlockByNumber(maincursor.blockNumber()).text().toUtf8())
-            maincursor.movePosition(QtGui.QTextCursor.EndOfBlock)
+                 findBlockByNumber(maincursor.blockNumber()).text())
+            maincursor.movePosition( QTextCursor.EndOfBlock)
             maincursor.insertText('\n'+line)
         else:
             block = self.document().findBlock(maincursor.selectionStart())
-            line = QtCore.QString()
+            line = u''
             while True:
                 cursor = self.textCursor()                                     
                 cursor.setPosition(block.position())
@@ -578,7 +514,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
                 if block.contains(maincursor.selectionEnd()):
                     break
                 block = block.next()
-            cursor.movePosition(QtGui.QTextCursor.EndOfBlock)
+            cursor.movePosition( QTextCursor.EndOfBlock)
             cursor.insertText(line)
         
     def gotoLine(self, line):
@@ -595,9 +531,9 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         """Comment the current line or selection"""
         maincursor = self.textCursor()
         if not maincursor.hasSelection():
-            maincursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+            maincursor.movePosition( QTextCursor.StartOfBlock)
             line = str(self.document().\
-                 findBlockByNumber(maincursor.blockNumber()).text().toUtf8())
+                 findBlockByNumber(maincursor.blockNumber()).text())
             if line.startswith('#'):
                 maincursor.deleteChar()
             else:
@@ -608,7 +544,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
                 cursor = self.textCursor()                                     
                 cursor.setPosition(block.position())
 
-                if str(block.text().toUtf8()).startswith('#'):
+                if str(block.text()).startswith('#'):
                     cursor.deleteChar()
                 else:
                     cursor.insertText("#")
@@ -622,7 +558,7 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         position_to = self.get_position(position_to)
         cursor = self.textCursor()
         cursor.setPosition(position_from)
-        cursor.setPosition(position_to, QtGui.QTextCursor.KeepAnchor)
+        cursor.setPosition(position_to,  QTextCursor.KeepAnchor)
         return cursor
 
         
@@ -631,15 +567,15 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         if position == 'cursor':
             pass
         elif position == 'sob':
-            cursor.movePosition(QtGui.QTextCursor.Start)
+            cursor.movePosition( QTextCursor.Start)
         elif position == 'sol':
-            cursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+            cursor.movePosition( QTextCursor.StartOfBlock)
         elif position == 'eol':
-            cursor.movePosition(QtGui.QTextCursor.EndOfBlock)
+            cursor.movePosition( QTextCursor.EndOfBlock)
         elif position == 'eof':
-            cursor.movePosition(QtGui.QTextCursor.End)
+            cursor.movePosition( QTextCursor.End)
         elif position == 'sof':
-            cursor.movePosition(QtGui.QTextCursor.Start)
+            cursor.movePosition( QTextCursor.Start)
         else:
             # Assuming that input argument was already a position
             return position
@@ -652,9 +588,5 @@ class KhtTextEdit(QtGui.QPlainTextEdit):
         """
         cursor = self.__select_text(position_from, position_to)
         text = cursor.selectedText()
-#        if not text.isEmpty():
-#            while text.endsWith("\n"):
-#                text.chop(1)
-#            while text.endsWith(u"\u2029"):
-#                text.chop(1)
-        return unicode(text)
\ No newline at end of file
+
+        return unicode(text)
